@@ -43,6 +43,7 @@
 #include <QTimer>
 #include <QVBoxLayout>
 #include <QWebEngineProfile>
+#include <QWebEngineSettings>
 
 #include "DwmSysLogger.hh"
 #include "DwmMcroverNWSRadarPageWidget.hh"
@@ -56,7 +57,7 @@ namespace Dwm {
     //------------------------------------------------------------------------
     NWSRadarPageWidget::NWSRadarPageWidget(QWidget *parent,
                                            Qt::WindowFlags f)
-        : QFrame(parent, f), _loaded(false)
+        : QFrame(parent, f), _loaded(false), _pageTweaked(false)
     {
       QFile  file;
       file.setFileName("/usr/share/javascript/jquery/jquery.min.js");
@@ -66,6 +67,8 @@ namespace Dwm {
         file.close();
       }
       _webEngView = new QWebEngineView();
+      _webEngView->settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, false);
+      
       connect(_webEngView, &QWebEngineView::loadFinished,
               this, &NWSRadarPageWidget::finishLoading);
       connect(_webEngView, &QWebEngineView::renderProcessTerminated,
@@ -85,6 +88,7 @@ namespace Dwm {
     void NWSRadarPageWidget::ReloadPage()
     {
       _webEngView->reload();
+      _pageTweaked = false;
       TweakPage(this);
     }
     
@@ -109,6 +113,7 @@ namespace Dwm {
     {
       _webEngView->page()->runJavaScript(_jQuery);
       if (ok) {
+        _pageTweaked = false;
         TweakPage(this);
       }
       else {
@@ -125,6 +130,7 @@ namespace Dwm {
     {
       if (! _loaded) {
         _webEngView->load(QUrl(radarURL.c_str()));
+        _webEngView->page()->profile()->setHttpCacheMaximumSize(10000000);
 #if 0
         qDebug() << "cookies:"
                  << _webEngView->page()->profile()->persistentCookiesPolicy();
@@ -136,12 +142,15 @@ namespace Dwm {
       }
       return;
     }
-    
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
     void NWSRadarPageWidget::TweakPage(QWidget *page)
     {
+      if (_pageTweaked)
+        return;
+      
       if (dynamic_cast<QWidget *>(this->parent()) == page) {
         // Remove the long title from the header.
         QString code = QStringLiteral("qt.jQuery('.title-long').remove()");
@@ -188,10 +197,17 @@ namespace Dwm {
                               "qt.jQuery('.control-item.info').css('width','90px')");
         _webEngView->page()->runJavaScript(code);
 
+#if 0
+        //  Disabled.  When enabled, a QtWebEngineProcess process will consume
+        //  a lot of memory (quickly grows to 1 gigabyte and beyond), as well
+        //  as increasing amounts of CPU.  This is bad on a Raspberry Pi.
+
         //  Hit the play button.
         code = QStringLiteral("qt.jQuery('.button-play').click();");
         _webEngView->page()->runJavaScript(code);
+#endif
         
+        _pageTweaked = true;
         Syslog(LOG_DEBUG, "Radar page tweaks done.");
       }
       return;
